==> 1.0.1.tar.gz: lib/payme_sdk_flutter.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

enum PaymeSdkFlutterLanguage { VN, EN }

enum PaymeSdkFlutterEnv { PRODUCTION, SANDBOX, DEV }

enum PaymeSdkFlutterPayCode {
  ATM,
  CREDIT,
  MANUAL_BANK,
  MOMO,
  PAYME,
  VN_PAY,
  ZALO_PAY,
}

class PaymeSdkFlutterConfig {
  final String appToken;
  final String publicKey;
  final String privateKey;
  final String secretKey;
  final Color primaryColor;
  final Color secondaryColor;
  final PaymeSdkFlutterLanguage language;
  final PaymeSdkFlutterEnv env;

  PaymeSdkFlutterConfig({
    required this.appToken,
    required this.publicKey,
    required this.privateKey,
    required this.secretKey,
    this.primaryColor = const Color(0xff75255b),
    this.secondaryColor = const Color(0xff9d455f),
    this.language = PaymeSdkFlutterLanguage.VN,
    this.env = PaymeSdkFlutterEnv.SANDBOX,
  });
}

class PaymeSdkFlutter {
  static const MethodChannel _channel =
      const MethodChannel('payme_sdk_flutter');

  static PaymeSdkFlutterEnv? currentEnv;

  static Future<String> login(
      String userId, String phone, PaymeSdkFlutterConfig config) async {
    final args = {
      'user_id': userId,
      'phone': phone,
      'app_token': config.appToken,
      'public_key': config.publicKey,
      'private_key': config.privateKey,
      'secret_key': config.secretKey,
      'primary_color': _hexFromColor(config.primaryColor),
      'secondary_color': _hexFromColor(config.secondaryColor),
      'language': _enumValue(config.language),
      'env': _enumValue(config.env),
    };
    final String version = await _channel.invokeMethod('login', args);
    currentEnv = config.env;
    return version;
  }

  static Future<void> logout() {
    return _channel.invokeMethod('logout');
  }

  static Future<dynamic> setLanguage(PaymeSdkFlutterLanguage lang) {
    final args = {'language': _enumValue(lang)};
    return _channel.invokeMethod('setLanguage', args);
  }

  static Future<dynamic> getAccountInfo() {
    return _channel.invokeMethod('getAccountInfo');
  }

  static Future<dynamic> getWalletInfo() {
    return _channel.invokeMethod('getWalletInfo');
  }

  static Future<dynamic> getSupportedServices() {
    return _channel.invokeMethod('getSupportedServices');
  }

  static Future<dynamic> openWallet() {
    return _channel.invokeMethod('openWallet');
  }

  static Future<dynamic> deposit(int amount) {
    final args = {'amount': amount};
    return _channel.invokeMethod('deposit', args);
  }

  static Future<dynamic> withdraw(int amount) {
    final args = {'amount': amount};
    return _channel.invokeMethod('withdraw', args);
  }

  static Future<dynamic> openKYC() {
    return _channel.invokeMethod('openKYC');
  }

  static Future<dynamic> pay(
    int amount,
    int storeId,
    String orderId,
    PaymeSdkFlutterPayCode payCode, {
    String? note,
    String? extraData,
    bool isShowResultUI = true,
  }) {
    final args = {
      'amount': amount,
      'store_id': storeId,
      'order_id': orderId,
      'pay_code': _enumValue(payCode),
      'note': note,
      'extra_data': extraData,
      'is_show_result_ui': isShowResultUI,
    };
    return _channel.invokeMethod('pay', args);
  }

  static Future<dynamic> transfer(int amount, {String note = ""}) {
    final args = {'amount': amount, 'note': note};
    return _channel.invokeMethod('transfer', args);
  }

  static Future<dynamic> openService(
      String serviceCode, String serviceDescription) {
    final args = {
      'service_code': serviceCode,
      'service_desc': serviceDescription
    };
    return _channel.invokeMethod('openService', args);
  }
}

String _hexFromColor(Color color) {
  return '#${color.value.toRadixString(16).substring(2, 8)}';
}

String _enumValue(dynamic e) {
  return e.toString().split('.').last;
}

==> 1.1.1.tar.gz: lib/payme_sdk_flutter.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

enum PaymeSdkFlutterLanguage { VN, EN }

enum PaymeSdkFlutterEnv { PRODUCTION, SANDBOX, DEV }

enum PaymeSdkFlutterPayCode {
  ATM,
  CREDIT,
  MANUAL_BANK,
  MOMO,
  PAYME,
  VN_PAY,
  ZALO_PAY,
}

class PaymeSdkFlutterConfig {
  final String appToken;
  final String publicKey;
  final String privateKey;
  final String secretKey;
  final Color primaryColor;
  final Color secondaryColor;
  final PaymeSdkFlutterLanguage language;
  final PaymeSdkFlutterEnv env;

  PaymeSdkFlutterConfig({
    required this.appToken,
    required this.publicKey,
    required this.privateKey,
    required this.secretKey,
    this.primaryColor = const Color(0xff75255b),
    this.secondaryColor = const Color(0xff9d455f),
    this.language = PaymeSdkFlutterLanguage.VN,
    this.env = PaymeSdkFlutterEnv.SANDBOX,
  });
}

class PaymeSdkFlutter {
  static const MethodChannel _channel =
      const MethodChannel('payme_sdk_flutter');

  static PaymeSdkFlutterEnv? currentEnv;

  static Future<String> login(
      String userId, String phone, PaymeSdkFlutterConfig config) async {
    final args = {
      'user_id': userId,
      'phone': phone,
      'app_token': config.appToken,
      'public_key': config.publicKey,
      'private_key': config.privateKey,
      'secret_key': config.secretKey,
      'primary_color': _hexFromColor(config.primaryColor),
      'secondary_color': _hexFromColor(config.secondaryColor),
      'language': _enumValue(config.language),
      'env': _enumValue(config.env),
    };
    final String version = await _channel.invokeMethod('login', args);
    currentEnv = config.env;
    return version;
  }

  static Future<void> logout() {
    return _channel.invokeMethod('logout');
  }

  static Future<dynamic> setLanguage(PaymeSdkFlutterLanguage lang) {
    final args = {'language': _enumValue(lang)};
    return _channel.invokeMethod('setLanguage', args);
  }

  static Future<dynamic> getAccountInfo() async {
    final rs = await _channel.invokeMethod('getAccountInfo');
    if (Platform.isAndroid && rs is String) {
      return jsonDecode(rs);
    }
    return rs;
  }

  static Future<dynamic> getWalletInfo() async {
    final rs = await _channel.invokeMethod('getWalletInfo');
    if (Platform.isAndroid && rs is String) {
      return jsonDecode(rs);
    }
    return rs;
  }

  static Future<dynamic> getSupportedServices() {
    return _channel.invokeMethod('getSupportedServices');
  }

  static Future<dynamic> openWallet() {
    return _channel.invokeMethod('openWallet');
  }

  static Future<dynamic> deposit({int? amount}) {
    final args = {'amount': amount};
    return _channel.invokeMethod('deposit', args);
  }

  static Future<dynamic> withdraw({int? amount}) {
    final args = {'amount': amount};
    return _channel.invokeMethod('withdraw', args);
  }

  static Future<dynamic> openKYC() {
    return _channel.invokeMethod('openKYC');
  }

  static Future<dynamic> pay(
    int amount,
    String storeId,
    String orderId,
    PaymeSdkFlutterPayCode payCode, {
    String? note,
    String? extraData,
    bool isShowResultUI = true,
  }) {
    final args = {
      'amount': amount,
      'store_id': storeId,
      'order_id': orderId,
      'pay_code': _enumValue(payCode),
      'note': note,
      'extra_data': extraData,
      'is_show_result_ui': isShowResultUI,
    };
    return _channel.invokeMethod('pay', args);
  }

  static Future<dynamic> transfer({int? amount, String note = ""}) {
    final args = {'amount': amount, 'note': note};
    return _channel.invokeMethod('transfer', args);
  }

  static Future<dynamic> openService(
      String serviceCode, String serviceDescription) {
    final args = {
      'service_code': serviceCode,
      'service_desc': serviceDescription
    };
    return _channel.invokeMethod('openService', args);
  }
}

String _hexFromColor(Color color) {
  return '#${color.value.toRadixString(16).substring(2, 8)}';
}

String _enumValue(dynamic e) {
  return e.toString().split('.').last;
}
